package org.openxma.dsl.generator.component;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.mwe.core.monitor.ProgressMonitor;
import org.eclipse.xtend.expression.ExecutionContext;
import org.eclipse.xtend.expression.IExecutionContextAware;

/**
 * Provides Java Extension functions for Xtend progress monitoring.
 */
public class MonitorExtension implements IExecutionContextAware {
	private ProgressMonitor monitor;

	public void setExecutionContext(ExecutionContext ctx) {
		this.monitor = ctx.getMonitor();
	}
	
	/**
	 * @return the URI from the resource of the given EObject
	 */
	public String getResourceUri(EObject eObject) {
		return eObject.eResource()!=null ? eObject.eResource().getURI().lastSegment() : "";
	}
	
	/**
	 * @return the URI#scheme part from the resource of the given EObject
	 */
	public String getResourceUriScheme(EObject eObject) {
		return eObject.eResource()!=null ? eObject.eResource().getURI().scheme() : "";
	}

	/**
	 * @see {@link ProgressMonitor#beginTask(String, int)}
	 */
	public void beginTask(String name, Long totalWork) {
		monitor.beginTask(name, totalWork.intValue());
	}

	/**
	 * @see {@link ProgressMonitor#done(ProgressMonitor)}
	 */
	public void done() {
		monitor.done();
	}

	/**
	 * @see {@link ProgressMonitor#internalWorked(double)}
	 */
	public void internalWorked(double work) {
		monitor.internalWorked(work);
	}

	/**
	 * @see {@link ProgressMonitor#isCanceled()}
	 */
	public boolean isCanceled() {
		return monitor.isCanceled();
	}

	/**
	 * @see {@link ProgressMonitor#setCanceled(boolean)}
	 */
	public void setCanceled(boolean value) {
		monitor.setCanceled(value);
	}

	/**
	 * @see {@link ProgressMonitor#beginTask(String)}
	 */
	public void setTaskName(String name) {
		monitor.setTaskName(name);
	}

	/**
	 * @see {@link ProgressMonitor#subTask(String)}
	 */
	public void subTask(String name) {
		monitor.subTask(name);
	}

	/**
	 * @see {@link ProgressMonitor#worked(int)}
	 */
	public void worked(Long work) {
		monitor.worked(work.intValue());
	}

}
